@@ -51,6 +51,7 @@ def sync(
     client: httpx.Client,
     page_size: Union[Unset, int] = 10,
     page_token: Union[Unset, str] = UNSET,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[ListQuantumProcessorsResponse]:
     url = "/v1/quantumProcessors"
 
@@ -58,6 +59,7 @@ def sync(
         page_size=page_size,
         page_token=page_token,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "get",
         url,
@@ -72,6 +74,7 @@ def sync_from_dict(
     client: httpx.Client,
     page_size: Union[Unset, int] = 10,
     page_token: Union[Unset, str] = UNSET,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[ListQuantumProcessorsResponse]:
 
     url = "/v1/quantumProcessors"
@@ -80,13 +83,12 @@ def sync_from_dict(
         page_size=page_size,
         page_token=page_token,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "get",
         url,
         **kwargs,
     )
-
     return _build_response(response=response)
 
 
@@ -96,6 +98,7 @@ async def asyncio(
     client: httpx.AsyncClient,
     page_size: Union[Unset, int] = 10,
     page_token: Union[Unset, str] = UNSET,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[ListQuantumProcessorsResponse]:
     url = "/v1/quantumProcessors"
 
@@ -103,9 +106,12 @@ async def asyncio(
         page_size=page_size,
         page_token=page_token,
     )
-
-    response = await client.request("get", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "get",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
 
 
@@ -115,6 +121,7 @@ async def asyncio_from_dict(
     client: httpx.AsyncClient,
     page_size: Union[Unset, int] = 10,
     page_token: Union[Unset, str] = UNSET,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[ListQuantumProcessorsResponse]:
 
     url = "/v1/quantumProcessors"
@@ -123,7 +130,10 @@ async def asyncio_from_dict(
         page_size=page_size,
         page_token=page_token,
     )
-
-    response = await client.request("get", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "get",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
