@@ -37,10 +37,12 @@ def _build_response(*, response: httpx.Response) -> Response[Reservation]:
 def sync(
     *,
     client: httpx.Client,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
     url = "/v1/reservations/{reservationId}"
 
     kwargs = _get_kwargs()
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "delete",
         url,
@@ -53,18 +55,18 @@ def sync(
 def sync_from_dict(
     *,
     client: httpx.Client,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
 
     url = "/v1/reservations/{reservationId}"
 
     kwargs = _get_kwargs()
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "delete",
         url,
         **kwargs,
     )
-
     return _build_response(response=response)
 
 
@@ -72,13 +74,17 @@ def sync_from_dict(
 async def asyncio(
     *,
     client: httpx.AsyncClient,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
     url = "/v1/reservations/{reservationId}"
 
     kwargs = _get_kwargs()
-
-    response = await client.request("delete", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "delete",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
 
 
@@ -86,12 +92,16 @@ async def asyncio(
 async def asyncio_from_dict(
     *,
     client: httpx.AsyncClient,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
 
     url = "/v1/reservations/{reservationId}"
 
     kwargs = _get_kwargs()
-
-    response = await client.request("delete", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "delete",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
