@@ -48,6 +48,7 @@ def sync(
     client: httpx.Client,
     quantum_processor_id: str,
     json_body: TranslateNativeQuilToEncryptedBinaryRequest,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[TranslateNativeQuilToEncryptedBinaryResponse]:
     url = "/v1/quantumProcessors/{quantumProcessorId}:translateNativeQuilToEncryptedBinary".format(
         quantumProcessorId=quantum_processor_id,
@@ -57,6 +58,7 @@ def sync(
         quantum_processor_id=quantum_processor_id,
         json_body=json_body,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "post",
         url,
@@ -71,6 +73,7 @@ def sync_from_dict(
     client: httpx.Client,
     quantum_processor_id: str,
     json_body_dict: Dict,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[TranslateNativeQuilToEncryptedBinaryResponse]:
     json_body = TranslateNativeQuilToEncryptedBinaryRequest.from_dict(json_body_dict)
 
@@ -82,13 +85,12 @@ def sync_from_dict(
         quantum_processor_id=quantum_processor_id,
         json_body=json_body,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
         "post",
         url,
         **kwargs,
     )
-
     return _build_response(response=response)
 
 
@@ -98,6 +100,7 @@ async def asyncio(
     client: httpx.AsyncClient,
     quantum_processor_id: str,
     json_body: TranslateNativeQuilToEncryptedBinaryRequest,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[TranslateNativeQuilToEncryptedBinaryResponse]:
     url = "/v1/quantumProcessors/{quantumProcessorId}:translateNativeQuilToEncryptedBinary".format(
         quantumProcessorId=quantum_processor_id,
@@ -107,9 +110,12 @@ async def asyncio(
         quantum_processor_id=quantum_processor_id,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "post",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
 
 
@@ -119,6 +125,7 @@ async def asyncio_from_dict(
     client: httpx.AsyncClient,
     quantum_processor_id: str,
     json_body_dict: Dict,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[TranslateNativeQuilToEncryptedBinaryResponse]:
     json_body = TranslateNativeQuilToEncryptedBinaryRequest.from_dict(json_body_dict)
 
@@ -130,7 +137,10 @@ async def asyncio_from_dict(
         quantum_processor_id=quantum_processor_id,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
-
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        "post",
+        url,
+        **kwargs,
+    )
     return _build_response(response=response)
