@@ -5,6 +5,7 @@ import attr
 from ..models.edge import Edge
 from ..models.family import Family
 from ..models.node import Node
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -48,35 +49,44 @@ class Architecture:
 
             nodes.append(nodes_item)
 
-        dct = {
-            "edges": edges,
-            "family": family,
-            "nodes": nodes,
-        }
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(
+            {
+                "edges": edges,
+                "family": family,
+                "nodes": nodes,
+            }
+        )
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Architecture":
+    def from_dict(src_dict: Dict[str, Any]) -> "Architecture":
+        d = src_dict.copy()
         edges = []
-        _edges = d["edges"]
+        _edges = d.pop("edges")
         for edges_item_data in _edges:
             edges_item = Edge.from_dict(edges_item_data)
 
             edges.append(edges_item)
 
-        family = Family(d["family"])
+        family = Family(d.pop("family"))
 
         nodes = []
-        _nodes = d["nodes"]
+        _nodes = d.pop("nodes")
         for nodes_item_data in _nodes:
             nodes_item = Node.from_dict(nodes_item_data)
 
             nodes.append(nodes_item)
 
-        return Architecture(
+        architecture = Architecture(
             edges=edges,
             family=family,
             nodes=nodes,
         )
+
+        return architecture
