@@ -15,21 +15,26 @@ class Parameter:
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
         name = self.name
 
-        dct = {
-            k: v
-            for k, v in {
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(
+            {
                 "name": name,
-            }.items()
-            if v != UNSET
-        }
+            }
+        )
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Parameter":
-        name = d["name"]
+    def from_dict(src_dict: Dict[str, Any]) -> "Parameter":
+        d = src_dict.copy()
+        name = d.pop("name")
 
-        return Parameter(
+        parameter = Parameter(
             name=name,
         )
+
+        return parameter
